package net.pricefx.common.apibuilder.compensationagreement;

import com.fasterxml.jackson.annotation.JsonIgnore;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public abstract class CompensationAgreementStructure {
    /**
     * The list of items to add in this level of the rba
     */
    @JsonIgnore
    public List<Item> items;

    /**
     * The level of the rba. If parentId == null then the root level is used
     */
    @JsonIgnore
    public String parentId;

    /**
     * A DTO that holds information about the new item (rebate type or folder) to be created.
     * This is created by the utility methods below. Do not use directly.
     */
    public class Item {
        public String labelOrRebateType;
        public int editabilityStatus;
        public boolean isFolder;
        public List<Item> items;
        public List<Map<String, Object>> inputs;
    }

    /**
     * Creates a new folder item, but does not add it to the list
     *
     * @param label The folder label
     * @return The new folder
     */
    public Item createFolder(String label) {
        Item i = new Item();
        i.labelOrRebateType = label;
        i.isFolder = true;
        return i;
    }

    /**
     * Creates and adds a new folder
     *
     * @param label The folder label
     * @return The new folder
     */
    public Item addFolder(String label) {
        return addFolder(label, null);
    }

    /**
     * Creates and adds a new folder
     *
     * @param label  The folder label
     * @param inputs New inputs of the folder
     * @return The new folder
     */
    public Item addFolder(String label, List<Map<String, Object>> inputs) {
        if (items == null) {
            items = new ArrayList<Item>();
        }
        Item i = createFolder(label);
        i.inputs = inputs;
        items.add(i);
        return i;
    }

    /**
     * Creates a new "part" item but does not add it
     *
     * @param name The uniqueName of the new Rebate Type
     * @return The new item
     */
    public Item createItem(String name) {
        Item i = new Item();
        i.labelOrRebateType = name;
        i.isFolder = false;
        return i;
    }

    /**
     * Creates and adds a new item
     *
     * @param name The uniqueName of the new Rebate Type
     * @return The new item
     */
    public Item addItem(String name) {
        return addItem(name, null);
    }

    /**
     * Creates and adds a new item
     *
     * @param name   The uniqueName of the new Rebate Type
     * @param inputs New inputs of the item
     * @return The new item
     */
    public Item addItem(String name, List<Map<String, Object>> inputs) {
        if (items == null) {
            items = new ArrayList<>();
        }
        Item i = createItem(name);
        i.inputs = inputs;
        items.add(i);
        return i;
    }
}
