package net.pricefx.common.apibuilder.rebateagreement;

import java.util.Map;

import net.pricefx.common.api.HeaderPhase;
import net.pricefx.common.apibuilder.IdGenerator;
import net.pricefx.common.apibuilder.Invocations;
import net.pricefx.common.apibuilder.MethodInvocation;
import net.pricefx.common.apibuilder.compensationagreement.CompensationAgreementBuilder;

/**
 *
 *  IMPORTANT: Please read super class notes on sequence of execution!
 *
 */
public class RebateAgreementBuilder extends BasicRebateAgreementBuilder<RebateAgreementBuilder> implements CompensationAgreementBuilder {

	// read only state, don't get propagated further, it is here for user convenience
	private final Object rebateAgreementView;
	private final RebateAgreementHelper helper;

	@SuppressWarnings("unchecked")
	RebateAgreementBuilder(String instanceId, String classId, IdGenerator idGenerator, Invocations<MethodInvocation> invocations, Object rebateAgreementView, HeaderPhase phase) {
		super(instanceId, classId, idGenerator, invocations,phase);
		this.rebateAgreementView = rebateAgreementView;
		this.helper = new RebateAgreementHelper((Map<String, Object>)rebateAgreementView);
	}

	/**
	 * Gets the full rebate agreement object as a nested map. This map contains all header inputs/outputs, and all line items (with their inputs/outputs).<p>
	 * Caution: when using Classic or Unity non-React user interface, then during pre-phase, the <i>raProcessor.rebateAgreementView</i> will NOT contain values of Outputs. The only exception are "overridable" outputs.
	 * This limitation is because of performance optimization of amount of data being sent between user interface and backend.
	 *
	 * @return The rebate agreement object
	 */
	public Object getRebateAgreementView() {
		addInvocation("getRebateAgreementView");
		return rebateAgreementView;
	}

	public RebateAgreementHelper getHelper() {
		addInvocation("getHelper");
		return helper;
	}

	public RebateAgreementBuilder addRebateAgreementStructure(RebateAgreementStructure structure) {
		addInvocation("addRebateAgreementStructure", structure);
		return this;
	}
	/**
	 * Creates and adds a new folder under the ROOT folder.
	 * <p>
	 * If you intend to add many folders and items, use the RebateAgreementStructure approach instead.
	 *
	 */
	public void addFolder(String label) {
		RebateAgreementStructure s = new RebateAgreementStructure();
		s.addFolder(label);
		addRebateAgreementStructure(s);
	}
}
