package net.pricefx.domain;

import com.fasterxml.jackson.annotation.JsonIgnore;

public abstract class NamedObject extends PartitionedObject {

	public static final String FIELD_UNIQUENAME = "uniqueName";
	public static final String FIELD_LABEL = "label";

	public NamedObject() {
	}

	public NamedObject(Partition partition, String uniqueName, String label) {
		super(partition);
		this.uniqueName = uniqueName;
		this.label = label;
	}

	private String uniqueName;
	private String label;

	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}

	public String getUniqueName() {
		return uniqueName;
	}

	public void setUniqueName(String uniqueName) {
		this.uniqueName = uniqueName;
	}

	@JsonIgnore
	public String getLabelOrUniqueName() {
		return label == null ? uniqueName : label;
	}

	@Override
	public String[] getSignificantFields() {
		return new String[] { FIELD_UNIQUENAME };
	}

	@Override
	public String toString(){
		return this.getUniqueName();
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((label == null) ? 0 : label.hashCode());
		result = prime * result
				+ ((uniqueName == null) ? 0 : uniqueName.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}

		NamedObject other = (NamedObject) obj;
		if (uniqueName == null) {
			if (other.uniqueName != null) {
				return false;
			}
		} else if (!uniqueName.equals(other.uniqueName)) {
			return false;
		}
		if (getPartition() == null) {
			if (other.getPartition()!= null) {
				return false;
			}
		} else if (!getPartition().equals(other.getPartition())) {
			return false;
		}
		return true;
	}


}
