package net.pricefx.formulaengine.optimization;

import java.util.Map;

/**
 * The {@link ModelPMMLContext} is exposed to model evaluations and calculations via <code>model</code> binding.
 * Warning: this interface is experimental and may change in future releases
 */
public interface ModelPMMLContext {

    /**
     * Loads a @link{PMMLEvaluator} from a given attachment of the model and returns it.
     * @param attachmentName name of the model attachment
     * @return the pmml evaluator
     */
    PMMLEvaluator fromAttachment(String attachmentName);

    /**
     * An evaluable PMML model.
     */
    interface PMMLEvaluator {

        /**
         * Evaluates the pmml model with the given inputs and returns a set of results.
         * @param inputs the pmml model evaluation input
         * @return the evaluation output
         */
        Map<String, ?> evaluate(Map<String, ?> inputs);
    }
}
