package net.pricefx.formulaengine.optimization;

import java.util.Collection;
import java.util.Map;

/**
 * The {@link ModelParallelCalculationFormulaSummaryContext} is exposed to model parallel calculation logics through the <code>model</code> binding.
 */
public interface ModelParallelCalculationFormulaSummaryContext extends ModelFormulaContextReadWrite {
    /**
     * @return all the items of this parallel calculation, all status considered
     */
    Collection<CalculationItem> calculationItems();

    interface CalculationItem extends ModelParallelCalculationFormulaItemContext.CalculationItem {
        enum Status {
            CREATED,
            CALCULATED,
            FAILED
        }

        /**
         * @return the status of the calculation
         * @see Status
         */
        Status status();

        /**
         * @return the calculation element results for this item
         * @throws IllegalStateException if the {@link #status()} is not {@link Status#CALCULATED}.
         */
        Map<String, Object> outputs();
    }
}
