package net.pricefx.formulaengine.scripting.portlets;

/**
 * Common interface for the portlet behavior.
 * Currently, only width and height modification is supported with default "px" pixels as a value unit.
 * Look into known implementations.
 */
public interface Portlet {

    /**
     * The pixels unit.
     */
    public static String UNIT_PX = "px";

    /**
     * Builder style method for setting the width in pixels.
     * @param width specify the width of the portlet (in pixels)
     * @return The current portlet object of the specified size.
     * @since 9.0 - Hurricane
     * @see <a href="https://pricefx.atlassian.net/wiki/spaces/KB/pages/4118937609/Layout+Configuration+Dashboard">Layout Configuration (Dashboard)</a> Knowledge Base article
     */
    Portlet withWidth(int width);

    /**
     * Builder style method for setting the height in pixels.
     * @param height specify the height of the portlet (in pixels)
     * @return The current portlet object of the specified size.
     * @since 9.0 - Hurricane
     * @see <a href="https://pricefx.atlassian.net/wiki/spaces/KB/pages/4118937609/Layout+Configuration+Dashboard">Layout Configuration (Dashboard)</a> Knowledge Base article
     */
    Portlet withHeight(int height);

    /**
     * Builder style method for setting width and height in pixels.
     * @param width specify the width of the portlet (in pixels)
     * @param height specify the height of the portlet (in pixels)
     * @return  The current portlet object of the specified size.
     * @since 9.0 - Hurricane
     * @see <a href="https://pricefx.atlassian.net/wiki/spaces/KB/pages/4118937609/Layout+Configuration+Dashboard">Layout Configuration (Dashboard)</a> Knowledge Base article
     */
    Portlet withLayout(int width, int height);


}
