package net.pricefx.server.util.metamodel;

import net.pricefx.common.api.pa.DataType;

import org.apache.metamodel.schema.AbstractColumn;
import org.apache.metamodel.schema.ColumnType;
import com.fasterxml.jackson.annotation.JsonIgnore;


public class Column extends AbstractColumn {

	private static final long serialVersionUID = 1L;
	
	protected final int columnNumber;
	protected final ColumnType type;
	protected final Table table;
	protected final String remarks;
	protected final boolean primaryKey;
	protected final String name;
    protected final String label;

    
    public Column(final String name,
    			  final String label,
    			  final ColumnType type, 
    			  final boolean primaryKey, 
    			  final int columnNumber, 
    			  final Table table, 
    			  final String remarks) {
        this.name = name;
        this.label = label;
        this.type = type;
        this.table = table;
        this.columnNumber = columnNumber;
        this.remarks = remarks;
        this.primaryKey = primaryKey;
    }

    public String getLabel(){
    	return label;
    }
    
    @Override
    public int getColumnNumber() {
        return columnNumber;
    }

    @Override
    public ColumnType getType() {
        return type;
    }

    @JsonIgnore
    @Override
    public Table getTable() {
        return table;
    }

    @Override
    public Boolean isNullable() {
        return null;
    }

    @Override
    public String getRemarks() {
        return remarks;
    }

    @Override
    public Integer getColumnSize() {
        return null;
    }

    public Integer getDecimalDigits() {
        return null;
    }

    @Override
    public String getNativeType() {
        return null;
    }

    @Override
    public boolean isIndexed() {
        return false;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public boolean isPrimaryKey() {
        return primaryKey;
    }

    @Override
    public String getQuote() {
        return null;
    }
    
    
    public static ColumnType toColumnType(final DataType dataType){
    	switch(dataType){
    	case STRING:
    		return ColumnType.VARCHAR;
    	case NUMBER:
    		return ColumnType.DECIMAL;
    	case DATE:
    		return ColumnType.DATE;
    	case BOOLEAN:
    		return ColumnType.BOOLEAN;
    	case DATETIME:
    		return ColumnType.TIMESTAMP;
    	case LOB:
    		return ColumnType.LONGVARCHAR;
    	case LONG:
    		return ColumnType.BIGINT;
    	default:
    		throw new IllegalArgumentException("Unsupported DataType: " + dataType);
    	}
    }
    
}